==> v2.2.0.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/mapper/ext/ExtVppRTeamMemberRoleMapper.java <==
package cn.kdan.pdf.tech.core.mapper.ext;

import cn.kdan.pdf.tech.core.mapper.VppRTeamMemberRoleMapper;
import cn.kdan.pdf.tech.core.model.VppRTeamMemberRole;
import cn.kdan.pdf.tech.core.pojo.vo.VppRTeamMemberRoleVO;
import cn.kdan.pdf.tech.core.pojo.vo.VppTeamAdminVO;
import cn.kdan.pdf.tech.core.pojo.vo.VppTeamMemberVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author tangxiangan
 */
public interface ExtVppRTeamMemberRoleMapper extends VppRTeamMemberRoleMapper {

    /**
     * 获取用户管理的团队
     *
     * @param memberId 用户id
     * @return List
     */
    List<VppRTeamMemberRoleVO> listMemberAdmin (@Param("memberId") String memberId);

    List<String> getTeamIdByAdminName (@Param("admin") String admin);

    /**
     * 获取团队下的成员(管理员)
     *
     * @param teamIds     团队id （不传则为查询公司所有团队）
     * @param roleIds        权限（不传则为查询所有用户）
     * @param queryString 用户名邮箱
     * @return List
     */
    List<VppTeamAdminVO> memberList(@Param("teamIds") List<String> teamIds, @Param("queryString") String queryString, @Param("roleIds") List<String> roleIds);

    /**
     * 获取团队下的成员（普通用户）
     *
     * @param teamIds
     * @param email
     * @param queryString
     * @param status
     * @return
     */
    List<VppTeamMemberVO> listForMember(@Param("teamIds") List<String> teamIds, @Param("email") String email, @Param("queryString") String queryString, @Param("status") String status, @Param("productCode") String productCode);


    /**
     * 获取团队所有关联关系
     * @param teamId 用户id
     * @return List
     */
    List<VppRTeamMemberRole> getAllByTeamId(@Param("teamId") String teamId);

    void cleanTeamAdmin(@Param("teamId")String teamId);

    void cleanTeamMember(String teamId);

    void changeTeamMember(@Param("teamId") String teamId, @Param("toTeamId") String toTeamId);
  }

==> v3.0.1.zip: pdf_tech_back_end/pdf-tech-core/src/main/java/cn/kdan/pdf/tech/core/mapper/ext/ExtVppRTeamMemberRoleMapper.java <==
package cn.kdan.pdf.tech.core.mapper.ext;

import cn.kdan.pdf.tech.core.mapper.VppRTeamMemberRoleMapper;
import cn.kdan.pdf.tech.core.model.VppRTeamMemberRole;
import cn.kdan.pdf.tech.core.pojo.vo.VppRTeamMemberRoleVO;
import cn.kdan.pdf.tech.core.pojo.vo.VppTeamAdminVO;
import cn.kdan.pdf.tech.core.pojo.vo.VppTeamMemberVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author tangxiangan
 */
public interface ExtVppRTeamMemberRoleMapper extends VppRTeamMemberRoleMapper {

    /**
     * 获取用户管理的团队
     *
     * @param memberId 用户id
     * @return List
     */
    List<VppRTeamMemberRoleVO> listMemberAdmin (@Param("memberId") String memberId);

    List<String> getTeamIdByAdminName (@Param("admin") String admin);

    /**
     * 获取团队下的成员(管理员)
     *
     * @param teamIds     团队id （不传则为查询公司所有团队）
     * @param roleIds        权限（不传则为查询所有用户）
     * @param queryString 用户名邮箱
     * @return List
     */
    List<VppTeamAdminVO> memberList(@Param("teamIds") List<String> teamIds, @Param("queryString") String queryString, @Param("roleIds") List<String> roleIds);

    /**
     * 获取团队下的成员（普通用户）
     *
     * @param teamIds
     * @param email
     * @param queryString
     * @param status
     * @param domain
     * @return
     */
    List<VppTeamMemberVO> listForMember(@Param("teamIds") List<String> teamIds, @Param("email") String email, @Param("queryString") String queryString, @Param("status") String status, @Param("productCode") String productCode, @Param("isSso") String isSso, @Param("domain") String domain);


    /**
     * 获取团队所有关联关系
     * @param teamId 用户id
     * @return List
     */
    List<VppRTeamMemberRole> getAllByTeamId(@Param("teamId") String teamId);

    void cleanTeamAdmin(@Param("teamId")String teamId);

    void cleanTeamMember(String teamId);

    void changeTeamMember(@Param("teamId") String teamId, @Param("toTeamId") String toTeamId);
  }
